@@ -1,7 +1,5 @@
 import logging
 
-from libBGG.PropertiedObject import PropertiedObject
-
 log = logging.getLogger(__name__)
 
 
@@ -10,7 +8,7 @@ class BoardgameException(Exception):
     pass
 
 
-class Boardgame(PropertiedObject):
+class Boardgame(object):
     '''Store information about a boardgame. The init function takes a list of valid
     proprties defined by boardgame.valid_properties. Properties that are lists can
     be given as a single item or as a list.'''
@@ -27,10 +25,9 @@ class Boardgame(PropertiedObject):
         for k, v in kwargs.items():
             setattr(self, k, v)
        
-        self._list_slots = ['designers', 'artists', 'categories', 'mechanics', 'families',
-                            'publishers', 'names']
+        _list_slots = ['designers', 'artists', 'categories', 'mechanics', 'families', 'publishers', 'names']
         # force these to be lists.
-        for l in self._list_slots:
+        for l in _list_slots:
             try:
                 if type(getattr(self, l)) != list:
                     setattr(self, l, [getattr(self, l)])
@@ -41,10 +38,10 @@ class Boardgame(PropertiedObject):
         log.debug('%s:' % self.name)
         for a in Boardgame.__slots__:
             if getattr(self, a, None):
-                if a in self._list_slots:
-                    log.debug('\t%s: %s' % (a, ', '.join(getattr(self, a))))
+                if type(a) is list:
+                    log.debug('\t%s: %s' % (a, ', '.join(getattr(self, a, []))))
                 else:
-                    log.debug('\t%s: %s' % (a, getattr(self, a)))
+                    log.debug('\t%s: %s' % (a, getattr(self, a, None)))
 
     def __unicode__(self):
         return '%s (%s) by %s' % (self.name, self.year, ', '.join(self.designers))
