@@ -1,5 +1,4 @@
 import logging
-from libBGG.PropertiedObject import PropertiedObject
 
 log = logging.getLogger(__name__)
 
@@ -9,7 +8,7 @@ class GuildException(Exception):
     pass
 
 
-class Guild(PropertiedObject):
+class Guild(object):
     '''Store information about a BGG Guild. The init function takes a list of valid
     proprties defined by Guild.valid_properties.'''
 
@@ -32,8 +31,8 @@ class Guild(PropertiedObject):
 
     def dump(self):
         log.debug('Guild %s:' % self.name)
-        for a in Rating.__slots__:
-            log.debug('\t%s: %s' % (a, getattr(self, a)))
+        for a in Guild.__slots__:
+            log.debug('\t%s: %s' % (a, getattr(self, a, None)))
 
     def __unicode__(self):
         return 'Guild %s (id=%s): %s' % (self.name, self.gid)
