@@ -1,6 +1,5 @@
 import logging
 
-from libBGG.PropertiedObject import PropertiedObject
 
 log = logging.getLogger(__name__)
 
@@ -10,7 +9,7 @@ class UserException(Exception):
     pass
 
 
-class User(PropertiedObject):
+class User(object):
     '''Store information about a BGG User. The init function takes a list of valid
     proprties defined by boardgame.__slots__. Properties that are lists can
     be given as a single item or as a list.'''
@@ -40,8 +39,8 @@ class User(PropertiedObject):
 
     def dump(self):
         log.debug('%s' % self.name)
-        for a in Rating.__slots__:
-            log.debug('\t%s: %s' % (a, getattr(self, a)))
+        for a in User.__slots__:
+            log.debug('\t%s: %s' % (a, getattr(self, a, 'Unknown')))
 
     @property
     def fullname(self):
